#ifndef __actions_all_h
#define __actions_all_h

void action_all_startup(void);

void action_execute_startup(void);
void action_debug_startup(void);
void action_showmenu_startup(void);
void action_showdesktop_startup(void);
void action_reconfigure_startup(void);
void action_exit_startup(void);
void action_restart_startup(void);
void action_cyclewindows_startup(void);
void action_breakchroot_startup(void);
void action_close_startup(void);
void action_move_startup(void);
void action_focus_startup(void);
void action_raise_startup(void);
void action_lower_startup(void);
void action_raiselower_startup(void);
void action_unfocus_startup(void);
void action_iconify_startup(void);
void action_fullscreen_startup(void);
void action_maximize_startup(void);
void action_moveresizeto_startup(void);
void action_moverelative_startup(void);
void action_shade_startup(void);
void action_kill_startup(void);
void action_omnipresent_startup(void);
void action_directionalwindows_startup(void);
void action_resize_startup(void);
void action_decorations_startup(void);
void action_desktop_startup(void);
void action_dock_startup(void);
void action_resizerelative_startup(void);
void action_addremovedesktop_startup(void);
void action_dockautohide_startup(void);
void action_layer_startup(void);
void action_movetoedge_startup(void);
void action_growtoedge_startup(void);
void action_if_startup(void);
void action_focustobottom_startup(void);
/* 3.4-compatibility */
void action_shadelowerraise_startup(void);

#endif
